==> Paws-0.28.tar.gz: Paws-0.28/lib/Paws/DS/RemoveIpRoutes.pm <==

package Paws::DS::RemoveIpRoutes;
  use Moose;
  has CidrIps => (is => 'ro', isa => 'ArrayRef[Str]', required => 1);
  has DirectoryId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'RemoveIpRoutes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::DS::RemoveIpRoutesResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DS::RemoveIpRoutes - Arguments for method RemoveIpRoutes on Paws::DS

=head1 DESCRIPTION

This class represents the parameters used for calling the method RemoveIpRoutes on the 
AWS Directory Service service. Use the attributes of this class
as arguments to method RemoveIpRoutes.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to RemoveIpRoutes.

As an example:

  $service_obj->RemoveIpRoutes(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> CidrIps => ArrayRef[Str]

IP address blocks that you want to remove.



=head2 B<REQUIRED> DirectoryId => Str

Identifier (ID) of the directory from which you want to remove the IP
addresses.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method RemoveIpRoutes in L<Paws::DS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/DS/RemoveIpRoutes.pm <==

package Paws::DS::RemoveIpRoutes;
  use Moose;
  has CidrIps => (is => 'ro', isa => 'ArrayRef[Str|Undef]', required => 1);
  has DirectoryId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'RemoveIpRoutes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::DS::RemoveIpRoutesResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DS::RemoveIpRoutes - Arguments for method RemoveIpRoutes on Paws::DS

=head1 DESCRIPTION

This class represents the parameters used for calling the method RemoveIpRoutes on the 
AWS Directory Service service. Use the attributes of this class
as arguments to method RemoveIpRoutes.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to RemoveIpRoutes.

As an example:

  $service_obj->RemoveIpRoutes(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> CidrIps => ArrayRef[Str|Undef]

IP address blocks that you want to remove.



=head2 B<REQUIRED> DirectoryId => Str

Identifier (ID) of the directory from which you want to remove the IP
addresses.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method RemoveIpRoutes in L<Paws::DS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
